from requests import *
from random import *
import os

def getDesktop():
    try:
        import winreg
        return winreg.QueryValueEx(winreg.OpenKey(winreg.HKEY_CURRENT_USER,r'Software\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders'),"Desktop")[0]
    except:
        return os.curdir

def setu(save = 1):
    # iw233
    url = ['https://iw233.cn/api.php?sort=random',
           'http://api.iw233.cn/api.php?sort=random',
           'http://ap1.iw233.cn/api.php?sort=random',
           'https://dev.iw233.cn/api.php?sort=random']

    data = get(choice(url)).content
    
    if not save:
        return data

    desk = getDesktop()
    with open(desk + '\\' + randbytes(3).hex() + '.jpg','wb') as f:
        f.write(data)

def setu_pro(save):
    pass
